@@ -1,8 +1,12 @@
 context("Key management")
 
+on_cran <- function() {
+  !interactive() && !isTRUE(as.logical(Sys.getenv("NOT_CRAN", "false")))
+}
+
 ## record current state before starting any tests
 env <- Sys.getenv("ORS_API_KEY", NA);
-key <- tryCatch(keyring::key_get("openrouteservice"), error = function(e) NA)
+key <- tryCatch(if (on_cran()) NA else keyring::key_get("openrouteservice"), error = function(e) NA)
 
 ## restore initial state
 on.exit({
@@ -13,18 +17,15 @@ on.exit({
 Sys.unsetenv("ORS_API_KEY")
 api_key_val <- "key_stored_in_keyring"
 
-skip_on_linux <- function() {
-  if (on_os("linux")) skip("Linux")
-  invisible(TRUE)
-}
-
 test_that("Set key in keyring", {
-  skip_on_linux()
+  skip_on_cran()
+  skip_on_os("linux")
   expect_silent(ors_api_key(api_key_val))
 })
 
 test_that("Get key from keyring", {
-  skip_on_linux()
+  skip_on_cran()
+  skip_on_os("linux")
   expect_identical(ors_api_key(), api_key_val)
 })
 
